@@ -5,7 +5,7 @@ use 5.006002;
 use strict;
 use warnings;
 
-our $VERSION = '0.128';
+our $VERSION = '0.129';
 
 use Exporter qw{ import };
 
@@ -90,7 +90,8 @@ is used.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-Coord-ECI-TLE-Iridium/issues>,
+or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -98,7 +99,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2020 by Thomas R. Wyant, III
+Copyright (C) 2011-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
